import pandas as pd

def skewed_split(input_csv, label_column, num_clients, name_prefix="Client"):
    """
    Splits the input dataset by label skew into multiple client files.

    Parameters:
    - input_csv (str): Path to the CSV file
    - label_column (str): Name of the label column
    - num_clients (int): Number of client splits
    - name_prefix (str): Prefix for output file names
    """
    df = pd.read_csv(input_csv)
    df_sorted = df.sort_values(by=label_column, ascending=True)
    split_size = len(df_sorted) // num_clients

    for i in range(num_clients):
        start = i * split_size
        end = (i + 1) * split_size if i != num_clients - 1 else len(df_sorted)
        client_df = df_sorted.iloc[start:end]
        filename = f'{name_prefix}_Client{i+1}_LDS.csv'
        client_df.to_csv(filename, index=False)
        print(f"Saved {filename} with {len(client_df)} rows.")

def main():
    import argparse
    parser = argparse.ArgumentParser()
    parser.add_argument('--input_csv', type=str, required=True)
    parser.add_argument('--label_column', type=str, required=True)
    parser.add_argument('--num_clients', type=int, required=True)
    parser.add_argument('--name_prefix', type=str, default="Client")
    args = parser.parse_args()

    skewed_split(args.input_csv, args.label_column, args.num_clients, args.name_prefix)
